@@ -62,49 +62,6 @@ class TestSriovConfig(base.TestCase):
         if os.path.isfile(sriov_config._UDEV_LEGACY_RULE_FILE):
             os.remove(sriov_config._UDEV_LEGACY_RULE_FILE)
 
-    def _write_numvfs(self, ifname, numvfs=0):
-        os.makedirs(sriov_config._get_dev_path(ifname))
-        numvfs_file = sriov_config._get_dev_path(ifname, 'sriov_numvfs')
-        with open(numvfs_file, 'w') as f:
-            f.write(str(numvfs))
-
-    def _save_action(self, action):
-        try:
-            self._action_order.append(action)
-        except AttributeError:
-            self._action_order = [action]
-
-    def setUp_udev_stubs(self):
-        def udev_monitor_setup_stub():
-            self._save_action('udev_monitor_setup')
-            return
-        self.stub_out('os_net_config.sriov_config.udev_monitor_setup',
-                      udev_monitor_setup_stub)
-
-        def udev_monitor_start_stub(observer):
-            self._save_action('udev_monitor_start')
-            return
-        self.stub_out('os_net_config.sriov_config.udev_monitor_start',
-                      udev_monitor_start_stub)
-
-        def udev_monitor_stop_stub(observer):
-            self._save_action('udev_monitor_stop')
-            return
-        self.stub_out('os_net_config.sriov_config.udev_monitor_stop',
-                      udev_monitor_stop_stub)
-
-        def trigger_udev_rules_stub():
-            self._save_action('trigger_udev_rules')
-            return
-        self.stub_out('os_net_config.sriov_config.trigger_udev_rules',
-                      trigger_udev_rules_stub)
-
-        def reload_udev_rules_stub():
-            self._save_action('reload_udev_rules')
-            return
-        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
-                      reload_udev_rules_stub)
-
     def test_add_udev_rules(self):
         """Test Add udev rules
 
@@ -117,7 +74,10 @@ class TestSriovConfig(base.TestCase):
         self.stub_out('os_net_config.sriov_config.get_pf_pci',
                       get_pf_pci_stub)
 
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         exp_udev_content = '# This file is autogenerated by os-net-config\n'\
                            'SUBSYSTEM=="net", ACTION=="add", DRIVERS=="?*", '\
@@ -139,7 +99,10 @@ class TestSriovConfig(base.TestCase):
         self.stub_out('os_net_config.sriov_config.get_pf_pci',
                       get_pf_pci_stub)
 
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         exp_udev_content = '# This file is autogenerated by os-net-config\n'\
                            'SUBSYSTEM=="net", ACTION=="add", DRIVERS=="?*", '\
@@ -160,7 +123,10 @@ class TestSriovConfig(base.TestCase):
         """Test Add udev rules for legacy sriov
 
         """
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         exp_udev_content = '# This file is autogenerated by os-net-config\n'\
             'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:8"\n'
@@ -172,7 +138,10 @@ class TestSriovConfig(base.TestCase):
         """Test modifying udev rules for legacy sriov
 
         """
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         udev_content = '# This file is autogenerated by os-net-config\n'\
             'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:10"\n'\
@@ -191,7 +160,10 @@ class TestSriovConfig(base.TestCase):
         """Test without changing udev rules for legacy sriov
 
         """
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         udev_content = '# This file is autogenerated by os-net-config\n'\
             'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:8"\n'\
@@ -210,7 +182,10 @@ class TestSriovConfig(base.TestCase):
         """Test appending udev rules for legacy sriov
 
         """
-        self.setUp_udev_stubs()
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
 
         udev_content = '# This file is autogenerated by os-net-config\n'\
             'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:8"\n'\
@@ -226,51 +201,6 @@ class TestSriovConfig(base.TestCase):
         f = open(udev_file.name, 'r')
         self.assertEqual(exp_udev_content, f.read())
 
-    def setUp_pf_stubs(self, vendor_id="0x8086"):
-        run_cmd = []
-        self.setUp_udev_stubs()
-
-        def run_ip_config_cmd_stub(*args, **kwargs):
-            run_cmd.append(' '.join(args))
-        self.stub_out('os_net_config.sriov_config.run_ip_config_cmd',
-                      run_ip_config_cmd_stub)
-
-        def cleanup_puppet_config_stub():
-            return
-        self.stub_out('os_net_config.sriov_config.cleanup_puppet_config',
-                      cleanup_puppet_config_stub)
-
-        def _wait_for_vf_creation_stub(pf_name, numvfs):
-            self._save_action('_wait_for_vf_creation_stub')
-            return
-        self.stub_out('os_net_config.sriov_config._wait_for_vf_creation',
-                      _wait_for_vf_creation_stub)
-
-        def get_vendor_id_stub(ifname):
-            return vendor_id
-        self.stub_out('os_net_config.sriov_config.get_vendor_id',
-                      get_vendor_id_stub)
-
-        def configure_switchdev_stub(pf_name):
-            self._save_action('configure_switchdev')
-            return
-        self.stub_out('os_net_config.sriov_config.configure_switchdev',
-                      configure_switchdev_stub)
-        self.set_numvfs = sriov_config.set_numvfs
-        self.get_numvfs = sriov_config.get_numvfs
-
-        def get_numvfs_stub(*args):
-            self._save_action('get_numvfs')
-            return self.get_numvfs(*args)
-        self.stub_out('os_net_config.sriov_config.get_numvfs',
-                      get_numvfs_stub)
-
-        def set_numvfs_stub(*args):
-            self._save_action('set_numvfs')
-            return self.set_numvfs(*args)
-        self.stub_out('os_net_config.sriov_config.set_numvfs',
-                      set_numvfs_stub)
-
     def test_configure_sriov_pf(self):
         """Test the numvfs setting for SR-IOV PF
 
@@ -283,13 +213,41 @@ class TestSriovConfig(base.TestCase):
 
         run_cmd = []
 
-        self.setUp_udev_stubs()
-
         def run_ip_config_cmd_stub(*args, **kwargs):
             run_cmd.append(' '.join(args))
         self.stub_out('os_net_config.sriov_config.run_ip_config_cmd',
                       run_ip_config_cmd_stub)
 
+        def udev_monitor_setup_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.udev_monitor_setup',
+                      udev_monitor_setup_stub)
+
+        def udev_monitor_start_stub(observer):
+            return
+        self.stub_out('os_net_config.sriov_config.udev_monitor_start',
+                      udev_monitor_start_stub)
+
+        def udev_monitor_stop_stub(observer):
+            return
+        self.stub_out('os_net_config.sriov_config.udev_monitor_stop',
+                      udev_monitor_stop_stub)
+
+        def cleanup_puppet_config_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.cleanup_puppet_config',
+                      cleanup_puppet_config_stub)
+
+        def trigger_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.trigger_udev_rules',
+                      trigger_udev_rules_stub)
+
+        def reload_udev_rules_stub():
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
+
         def _wait_for_vf_creation_stub(pf_name, numvfs):
             numvfs_pair = {"p2p1": 10, "p2p2": 12}
             self.assertEqual(numvfs_pair[pf_name], numvfs)
@@ -306,8 +264,17 @@ class TestSriovConfig(base.TestCase):
                      {"device_type": "pf", "name": "p2p2", "numvfs": 12,
                       "promisc": "off", "link_mode": "legacy"}]
 
-        for ifname in ['p2p1', 'p2p2']:
-            self._write_numvfs(ifname)
+        os.makedirs(sriov_config._SYS_CLASS_NET + "/p2p1/device")
+        os.makedirs(sriov_config._SYS_CLASS_NET + "/p2p2/device")
+        f = open(sriov_config._SYS_CLASS_NET + "/p2p1/device/sriov_numvfs",
+                 "w+")
+        f.write("0")
+        f.close()
+
+        f = open(sriov_config._SYS_CLASS_NET + "/p2p2/device/sriov_numvfs",
+                 "w+")
+        f.write("0")
+        f.close()
 
         utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, pf_config)
         sriov_config.configure_logger(debug=True)
@@ -318,101 +285,6 @@ class TestSriovConfig(base.TestCase):
         self.assertEqual(10, sriov_config.get_numvfs('p2p1'))
         self.assertEqual(12, sriov_config.get_numvfs('p2p2'))
 
-    def test_configure_sriov_pf_nicpart(self):
-        """Test the udev rules created for legacy mode of SR-IOV PF
-
-        In this case, the VF(s) are already bound/attached
-        """
-
-        self.setUp_pf_stubs()
-
-        exp_udev_content = '# This file is autogenerated by os-net-config\n'\
-            'KERNEL=="p2p2", RUN+="/bin/os-net-config-sriov -n %k:12"\n'
-        exp_actions = [
-            'udev_monitor_setup',
-            'udev_monitor_start',
-            'set_numvfs',
-            'get_numvfs',
-            '_wait_for_vf_creation_stub',
-            'get_numvfs',
-            'reload_udev_rules',
-            'set_numvfs',
-            'get_numvfs',
-            '_wait_for_vf_creation_stub',
-            'get_numvfs',
-            'udev_monitor_stop',
-        ]
-
-        pf_config = [{"device_type": "pf", "name": "p2p1", "numvfs": 10,
-                      "promisc": "on", "link_mode": "legacy"},
-                     {"device_type": "pf", "name": "p2p2", "numvfs": 12,
-                      "promisc": "off", "link_mode": "legacy"},
-                     {"device": {"name": "p2p1", "vfid": 0},
-                      "device_type": "vf", "name": "p2p1v0", "max_tx_rate": 0,
-                      "min_tx_rate": 0, "pci_address": "0000:18:0a.0",
-                      "trust": "on", "spoofcheck": "off"}]
-
-        for ifname in ['p2p1', 'p2p2']:
-            self._write_numvfs(ifname)
-
-        self._action_order = []
-        utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, pf_config)
-        sriov_config.configure_logger(debug=True)
-        sriov_config.configure_sriov_pf()
-        self.assertEqual(exp_actions, self._action_order)
-        f = open(sriov_config._UDEV_LEGACY_RULE_FILE, 'r')
-        self.assertEqual(exp_udev_content, f.read())
-        self.assertEqual(12, sriov_config.get_numvfs('p2p2'))
-
-    def test_configure_sriov_pf_non_nicpart(self):
-        """Test the udev rules created for legacy mode of SR-IOV PF
-
-        In this case, the nic partitioned VF(s) are not attached
-        """
-
-        self.setUp_pf_stubs()
-
-        exp_udev_content = '# This file is autogenerated by os-net-config\n'\
-            'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:10"\n'\
-            'KERNEL=="p2p2", RUN+="/bin/os-net-config-sriov -n %k:12"\n'
-        exp_actions = [
-            'udev_monitor_setup',
-            'udev_monitor_start',
-            'reload_udev_rules',
-            'set_numvfs',
-            'get_numvfs',
-            '_wait_for_vf_creation_stub',
-            'get_numvfs',
-            'reload_udev_rules',
-            'set_numvfs',
-            'get_numvfs',
-            '_wait_for_vf_creation_stub',
-            'get_numvfs',
-            'udev_monitor_stop',
-        ]
-
-        pf_config = [{"device_type": "pf", "name": "p2p1", "numvfs": 10,
-                      "promisc": "on", "link_mode": "legacy"},
-                     {"device_type": "pf", "name": "p2p2", "numvfs": 12,
-                      "promisc": "off", "link_mode": "legacy"},
-                     {"device": {"name": "eno3", "vfid": 1},
-                      "device_type": "vf", "name": "eno3v0", "max_tx_rate": 0,
-                      "min_tx_rate": 0, "pci_address": "0000:18:0e.1",
-                      "trust": "on", "spoofcheck": "off"}]
-
-        for ifname in ['p2p1', 'p2p2']:
-            self._write_numvfs(ifname)
-
-        self._action_order = []
-        utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, pf_config)
-        sriov_config.configure_logger(debug=True)
-        sriov_config.configure_sriov_pf()
-        self.assertEqual(exp_actions, self._action_order)
-        f = open(sriov_config._UDEV_LEGACY_RULE_FILE, 'r')
-        self.assertEqual(exp_udev_content, f.read())
-        self.assertEqual(10, sriov_config.get_numvfs('p2p1'))
-        self.assertEqual(12, sriov_config.get_numvfs('p2p2'))
-
     def test_cleanup_puppet_config_deprecation(self):
         """Test the cleanup of puppet-tripleo generated config file.
 
@@ -484,21 +356,33 @@ class TestSriovConfig(base.TestCase):
     def test_numvfs_config(self):
         """Test the numvfs config with valid arguments"""
 
-        self._write_numvfs('p2p1')
+        os.makedirs(sriov_config._SYS_CLASS_NET + "/p2p1/device")
+        f = open(sriov_config._SYS_CLASS_NET + "/p2p1/device/sriov_numvfs",
+                 "w+")
+        f.write("0")
+        f.close()
         self.assertEqual(None, sriov_config.main(['ARG0', '-n', 'p2p1:15']))
         self.assertEqual(15, sriov_config.get_numvfs('p2p1'))
 
     def test_numvfs_invalid_params(self):
         """Test the numvfs config with invalid arguments"""
 
-        self._write_numvfs('p2p1')
+        os.makedirs(sriov_config._SYS_CLASS_NET + "/p2p1/device")
+        f = open(sriov_config._SYS_CLASS_NET + "/p2p1/device/sriov_numvfs",
+                 "w+")
+        f.write("0")
+        f.close()
         self.assertEqual(1, sriov_config.main(['ARG0', '-n', 'p2p1:15a']))
         self.assertEqual(0, sriov_config.get_numvfs('p2p1'))
 
     def test_numvfs_preconfigured(self):
         """Test the numvfs config while its already configured"""
 
-        self._write_numvfs('p2p1', 10)
+        os.makedirs(sriov_config._SYS_CLASS_NET + "/p2p1/device")
+        f = open(sriov_config._SYS_CLASS_NET + "/p2p1/device/sriov_numvfs",
+                 "w+")
+        f.write("10")
+        f.close()
         self.assertEqual(None, sriov_config.main(['ARG0', '-n', 'p2p1:15']))
         self.assertEqual(10, sriov_config.get_numvfs('p2p1'))
 
