@@ -22,12 +22,12 @@ import six
 import time
 import yaml
 
-from os_net_config import common
 from os_net_config import sriov_config
 from oslo_concurrency import processutils
 
 logger = logging.getLogger(__name__)
 _SYS_CLASS_NET = '/sys/class/net'
+_SYS_BUS_PCI_DEV = '/sys/bus/pci/devices'
 # File to contain the DPDK mapped nics, as nic name will not be available after
 # binding driver, which is required for correct nic numbering.
 # Format of the file (list mapped nic's details):
@@ -44,14 +44,14 @@ _SRIOV_CONFIG_SERVICE_FILE = "/etc/systemd/system/sriov_config.service"
 _SRIOV_CONFIG_DEVICE_CONTENT = """[Unit]
 Description=SR-IOV numvfs configuration
 After=systemd-udev-settle.service openibd.service
-Before=network-pre.target openvswitch.service
+Before=openvswitch.service
 
 [Service]
 Type=oneshot
 ExecStart=/usr/bin/os-net-config-sriov
 
 [Install]
-WantedBy=basic.target
+WantedBy=multi-user.target
 """
 
 # VPP startup operational configuration file. The content of this file will
@@ -63,6 +63,10 @@ class InvalidInterfaceException(ValueError):
     pass
 
 
+class OvsDpdkBindException(ValueError):
+    pass
+
+
 class VppException(ValueError):
     pass
 
@@ -150,6 +154,19 @@ def is_real_nic(interface_name):
         return False
 
 
+def _is_vf(pci_address):
+
+    # If DPDK drivers are bound on a VF, then the path _SYS_CLASS_NET
+    # wouldn't exist. Instead we look for the path
+    # /sys/bus/pci/devices/<PCI addr>/physfn to understand if the device
+    # is actually a VF. This path could be used by VFs not bound with
+    # DPDK drivers as well
+
+    vf_path_check = _SYS_BUS_PCI_DEV + '/%s/physfn' % pci_address
+    is_sriov_vf = os.path.isdir(vf_path_check)
+    return is_sriov_vf
+
+
 def _is_vf_by_name(interface_name, check_mapping_file=False):
     vf_path_check = _SYS_CLASS_NET + '/%s/device/physfn' % interface_name
     is_sriov_vf = os.path.isdir(vf_path_check)
@@ -236,7 +253,7 @@ def _ordered_nics(check_active):
             # If the DPDK drivers are bound to a VF, the same needs
             # to be skipped for the NIC ordering
             nic = item['name']
-            if common.is_vf(item['pci_address']):
+            if _is_vf(item['pci_address']):
                 logger.info("%s is a VF, skipping it for NIC ordering" % nic)
             elif _is_vf_by_name(nic, True):
                 logger.info("%s is a VF, skipping it for NIC ordering" % nic)
@@ -285,23 +302,33 @@ def bind_dpdk_interfaces(ifname, driver, noop):
                     processutils.execute('modprobe', 'vfio-pci')
                 except processutils.ProcessExecutionError:
                     msg = "Failed to modprobe vfio-pci module"
-                    raise common.OvsDpdkBindException(msg)
+                    raise OvsDpdkBindException(msg)
 
             mac_address = interface_mac(ifname)
             vendor_id = get_vendor_id(ifname)
-            err = common.set_driverctl_override(pci_address, driver)
-            if not err:
-                _update_dpdk_map(ifname, pci_address, mac_address, driver)
-                # Not like other nics, beacause mellanox nics keep the
-                # interface after binding it to dpdk, so we are adding
-                # ethtool command with 10 attempts after binding the driver
-                # just to make sure that the interface is initialized
-                # successfully in order not to fail in each of this cases:
-                # - get_dpdk_devargs() in case of OvsDpdkPort and
-                #   OvsDpdkBond.
-                # - bind_dpdk_interface() in case of OvsDpdkBond.
-                if vendor_id == common.MLNX_VENDOR_ID:
-                    processutils.execute('ethtool', '-i', ifname, attempts=10)
+            try:
+                out, err = processutils.execute('driverctl', 'set-override',
+                                                pci_address, driver)
+                if err:
+                    msg = "Failed to bind dpdk interface err - %s" % err
+                    raise OvsDpdkBindException(msg)
+                else:
+                    _update_dpdk_map(ifname, pci_address, mac_address, driver)
+                    # Not like other nics, beacause mellanox nics keep the
+                    # interface after binding it to dpdk, so we are adding
+                    # ethtool command with 10 attempts after binding the driver
+                    # just to make sure that the interface is initialized
+                    # successfully in order not to fail in each of this cases:
+                    # - get_dpdk_devargs() in case of OvsDpdkPort and
+                    #   OvsDpdkBond.
+                    # - bind_dpdk_interface() in case of OvsDpdkBond.
+                    if vendor_id == "0x15b3":
+                        processutils.execute('ethtool', '-i', ifname,
+                                             attempts=10)
+
+            except processutils.ProcessExecutionError:
+                msg = "Failed to bind interface %s with dpdk" % ifname
+                raise OvsDpdkBindException(msg)
         else:
             # Check if the pci address is already fetched and stored.
             # If the pci address could not be fetched from dpdk_mapping.yaml
@@ -309,7 +336,7 @@ def bind_dpdk_interfaces(ifname, driver, noop):
             # available nor bound with dpdk.
             if not get_stored_pci_address(ifname, noop):
                 msg = "Interface %s cannot be found" % ifname
-                raise common.OvsDpdkBindException(msg)
+                raise OvsDpdkBindException(msg)
     else:
         logger.info('Interface %(name)s bound to DPDK driver %(driver)s '
                     'using driverctl command' %
@@ -376,14 +403,6 @@ def get_device_id(ifname):
         return
 
 
-def is_mellanox_interface(ifname):
-    MLNX_VENDOR_ID = "0x15b3"
-    vendor_id = get_vendor_id(ifname)
-    if vendor_id == MLNX_VENDOR_ID:
-        return True
-    return False
-
-
 def get_interface_driver(ifname):
     try:
         uevent = '%s/%s/device/uevent' % (_SYS_CLASS_NET, ifname)
@@ -469,7 +488,7 @@ def _get_dpdk_mac_address(name):
 
 
 def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
-                        link_mode='legacy', steering_mode=None):
+                        link_mode='legacy'):
     if not noop:
         cur_numvfs = sriov_config.get_numvfs(ifname)
         if cur_numvfs > 0 and cur_numvfs != numvfs:
@@ -482,8 +501,6 @@ def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
                 if promisc is not None:
                     item['promisc'] = promisc
                 item['link_mode'] = link_mode
-                if steering_mode is not None:
-                    item['steering_mode'] = steering_mode
                 break
         else:
             new_item = {}
@@ -493,8 +510,6 @@ def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
             if promisc is not None:
                 new_item['promisc'] = promisc
             new_item['link_mode'] = link_mode
-            if steering_mode is not None:
-                new_item['steering_mode'] = steering_mode
             sriov_map.append(new_item)
 
         write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, sriov_map)
@@ -507,7 +522,7 @@ def _get_sriov_map():
 
 
 def _set_vf_fields(vf_name, vlan_id, qos, spoofcheck, trust, state, macaddr,
-                   promisc, pci_address, min_tx_rate, max_tx_rate, driver):
+                   promisc, pci_address, min_tx_rate, max_tx_rate):
     vf_configs = {}
     vf_configs['name'] = vf_name
     if vlan_id != 0:
@@ -526,8 +541,6 @@ def _set_vf_fields(vf_name, vlan_id, qos, spoofcheck, trust, state, macaddr,
     vf_configs['macaddr'] = macaddr
     vf_configs['promisc'] = promisc
     vf_configs['pci_address'] = pci_address
-    if driver:
-        vf_configs['driver'] = driver
     return vf_configs
 
 
@@ -540,7 +553,7 @@ def _clear_empty_values(vf_config):
 def update_sriov_vf_map(pf_name, vfid, vf_name, vlan_id=0, qos=0,
                         spoofcheck=None, trust=None, state=None, macaddr=None,
                         promisc=None, pci_address=None,
-                        min_tx_rate=0, max_tx_rate=0, driver=None):
+                        min_tx_rate=0, max_tx_rate=0):
     sriov_map = _get_sriov_map()
     for item in sriov_map:
         if (item['device_type'] == 'vf' and
@@ -548,8 +561,7 @@ def update_sriov_vf_map(pf_name, vfid, vf_name, vlan_id=0, qos=0,
            item['device'].get('vfid') == vfid):
             item.update(_set_vf_fields(vf_name, vlan_id, qos, spoofcheck,
                                        trust, state, macaddr, promisc,
-                                       pci_address, min_tx_rate, max_tx_rate,
-                                       driver))
+                                       pci_address, min_tx_rate, max_tx_rate))
             _clear_empty_values(item)
             break
     else:
@@ -558,8 +570,7 @@ def update_sriov_vf_map(pf_name, vfid, vf_name, vlan_id=0, qos=0,
         new_item['device'] = {"name": pf_name, "vfid": vfid}
         new_item.update(_set_vf_fields(vf_name, vlan_id, qos, spoofcheck,
                                        trust, state, macaddr, promisc,
-                                       pci_address, min_tx_rate, max_tx_rate,
-                                       driver))
+                                       pci_address, min_tx_rate, max_tx_rate))
         _clear_empty_values(new_item)
         sriov_map.append(new_item)
 
@@ -575,32 +586,6 @@ def _get_vf_name_from_map(pf_name, vfid):
             return item['name']
 
 
-def nicpart_udev_rules_check():
-    """Clean-up UDEV rules on initial deployment
-
-     After writing sriov_config.yaml file, clean-up
-     UDEV rule(s) of PF for which VFs are used by host
-    """
-    if not os.path.exists(sriov_config._UDEV_LEGACY_RULE_FILE):
-        return
-
-    udev = '^KERNEL=="(.*)", RUN.*'
-    udev_reg = re.compile(udev, 0)
-
-    with open(sriov_config._UDEV_LEGACY_RULE_FILE, "r") as fp:
-        rules = fp.readlines()
-
-    with open(sriov_config._UDEV_LEGACY_RULE_FILE, "w") as fp:
-        for line in rules:
-            match = udev_reg.match(line)
-            if match:
-                dev_name = match.group(1)
-                if not sriov_config.is_partitioned_pf(dev_name):
-                    fp.write(line)
-            else:
-                fp.write(line)
-
-
 def _configure_sriov_config_service():
     """Generate the sriov_config.service
 
@@ -622,7 +607,6 @@ def configure_sriov_pfs(execution_from_cli=False, restart_openvswitch=False):
 def configure_sriov_vfs():
     logger.info("Configuring VFs now")
     sriov_config.configure_sriov_vf()
-    nicpart_udev_rules_check()
 
 
 def get_vf_devname(pf_name, vfid):
